@@ -64,9 +64,9 @@ class Run(Annotate):  # noqa: D101
             --antismash-sideload          write an AntiSMASH v6 sideload JSON
                                           file next to the output files.
             --force-tsv                   always write TSV output files even
-                                          when they are empty (e.g. because 
+                                          when they are empty (e.g. because
                                           no genes or no clusters were found).
-                                          
+
 
         Parameters - Gene Calling:
             -M, --mask                    Enable unknown region masking to
@@ -82,6 +82,9 @@ class Run(Annotate):  # noqa: D101
                                           to be included. [default: 1e-9]
 
         Parameters - Cluster Detection:
+            --no-pad                      disable padding of gene sequences
+                                          (used to predict BGCs in contigs
+                                          smaller than the CRF window length).
             -c <N>, --cds <N>             the minimum number of coding sequences a
                                           valid cluster must contain. [default: 3]
             -m <m>, --threshold <m>       the probability threshold for cluster
@@ -138,6 +141,7 @@ class Run(Annotate):  # noqa: D101
             self.antismash_sideload = self._check_flag("--antismash-sideload", bool)
             self.force_tsv = self._check_flag("--force-tsv", bool)
             self.mask = self._check_flag("--mask", bool)
+            self.no_pad = self._check_flag("--no-pad", bool)
         except InvalidArgument:
             raise CommandExit(1)
 
@@ -175,7 +179,7 @@ class Run(Annotate):  # noqa: D101
         task = self.progress.add_task("Predicting marginals", total=len(genes), unit=unit, precision="")
         return list(crf.predict_probabilities(
             self.progress.track(genes, task_id=task, total=len(genes)),
-            cpus=self.jobs
+            pad=not self.no_pad,
         ))
 
     def _extract_clusters(self, genes):
